@@ -88,6 +88,13 @@ class BackGroundJobs(object):
 
 
 class SQLCli(object):
+    # 连接配置信息
+    # Database
+    # ClassName
+    # FullName
+    # JDBCURL
+    # ODBCURL
+    # JDBCProp
     connection_configs = None
 
     # 数据库连接的各种参数
@@ -217,6 +224,14 @@ class SQLCli(object):
 
     def register_special_commands(self):
 
+        # 加载SQL映射文件
+        register_special_command(
+            self.load_driver,
+            command="loaddriver",
+            description="load SQL Driver file.",
+            hidden=False
+        )
+
         # 加载SQL映射文件
         register_special_command(
             self.load_sqlmap,
@@ -407,6 +422,74 @@ class SQLCli(object):
                 None,
                 "Please wait all background process complete.")
 
+    # 加载数据库驱动
+    # 标准的默认驱动程序并不需要使用这个函数，这个函数是用来覆盖标准默认驱动程序的加载信息
+    def load_driver(self, arg, **_):
+        if arg == "":      # 显示当前的Driver配置
+            m_Result = []
+            for row in self.connection_configs:
+                m_Result.append([row["Database"], row["ClassName"], row["FullName"],
+                                 row["JDBCURL"], row["ODBCURL"], row["JDBCProp"]])
+            yield (
+                "Current Drivers: ",
+                m_Result,
+                ["Database", "ClassName", "FileName", "JDBCURL", "ODBCURL", "JDBCProp"],
+                None,
+                "Driver loaded."
+            )
+            return
+
+        # 解析命令参数
+        options_parameters = str(arg).split()
+
+        # 只有一个参数，打印当前Database的Driver情况
+        if len(options_parameters) == 1:
+            m_DriverName = str(options_parameters[0])
+            m_Result = []
+            for row in self.connection_configs:
+                if row["Database"] == m_DriverName:
+                    m_Result.append([row["Database"], row["ClassName"], row["FullName"],
+                                     row["JDBCURL"], row["ODBCURL"], row["JDBCProp"]])
+                    break
+            yield (
+                "Current Drivers: ",
+                m_Result,
+                ["Database", "ClassName", "FileName", "JDBCURL", "ODBCURL", "JDBCProp"],
+                None,
+                "Driver loaded."
+            )
+            return
+
+        # 两个参数，替换当前Database的Driver
+        if len(options_parameters) == 2:
+            m_DriverName = str(options_parameters[0])
+            m_DriverFullName = str(options_parameters[1])
+            if self.sqlscript is None:
+                m_DriverFullName = os.path.join(sys.path[0], m_DriverFullName)
+            else:
+                m_DriverFullName = os.path.abspath(os.path.join(os.path.dirname(self.sqlscript), m_DriverFullName))
+            if not os.path.isfile(m_DriverFullName):
+                raise SQLCliException("Driver not loaded. file [" + m_DriverFullName + "] does not exist!")
+            bFound = False
+            for nPos in range(0, len(self.connection_configs)):
+                if self.connection_configs[nPos]["Database"].upper() == m_DriverName.strip().upper():
+                    m_Config = self.connection_configs[nPos]
+                    m_Config["FullName"] = [m_DriverFullName,]
+                    bFound = True
+                    self.connection_configs[nPos] = m_Config
+            if not bFound:
+                raise SQLCliException("Driver not loaded. Please config it in configfile first.")
+            yield (
+                None,
+                None,
+                None,
+                None,
+                "Driver [" + m_DriverName.strip() + "] loaded."
+            )
+            return
+
+        raise SQLCliException("Bad command.  loaddriver [database] [new jar name]")
+
     # 加载数据库SQL映射
     def load_sqlmap(self, arg, **_):
         self.SQLOptions.set("SQLREWRITE", "ON")
@@ -1873,14 +1956,15 @@ class SQLCli(object):
                                 "ODBCURL": m_ODBCURL}
                 self.connection_configs.append(m_Jar_Config)
 
-        # 处理传递的映射文件
+        # 处理传递的映射文件, 首先加载参数的部分，如果环境变量里头有设置，则环境变量部分会叠加参数部分
+        self.SQLOptions.set("SQLREWRITE", "OFF")
         if self.sqlmap is not None:   # 如果传递的参数，有Mapping，以参数为准，先加载参数中的Mapping文件
             self.SQLMappingHandler.Load_SQL_Mappings(self.sqlscript, self.sqlmap)
-        elif "SQLCLI_SQLMAPPING" in os.environ:     # 如果没有参数，则以环境变量中的信息为准
+            self.SQLOptions.set("SQLREWRITE", "ON")
+        if "SQLCLI_SQLMAPPING" in os.environ:     # 如果没有参数，则以环境变量中的信息为准
             if len(os.environ["SQLCLI_SQLMAPPING"].strip()) > 0:
                 self.SQLMappingHandler.Load_SQL_Mappings(self.sqlscript, os.environ["SQLCLI_SQLMAPPING"])
-        else:  # 任何地方都没有sql mapping信息，设置QUERYREWRITE为OFF
-            self.SQLOptions.set("SQLREWRITE", "OFF")
+                self.SQLOptions.set("SQLREWRITE", "ON")
 
         # 给Page做准备，PAGE显示的默认换页方式.
         if not os.environ.get("LESS"):
